/*
Week 4 Lab 4: Random Numbers and Loops

Author: Sergio J. Vargas
Date: July 28, 2020

Description:
Code for Card Picker. The program is set up to create a deck with four suits
containing 13 cards in each suit. The cards are then appended to a deck and the
deck is shuffled using the Fisher-Yates algorithm. Finally the cards are 'Drawn'
by a button in the HTML and prepended to a list to keep previous draws in view.

Update:
Added user form validation. Added a form to add number of cards in a deal as
well as adding a number of hands in the deal. The shuffle works but everyone
would get the following card from the deck. I was puzzled as to how to make it
deal one card per row. I did have an idea on how but it would involve changing
the algorithm and would only marginally increase the shuffling "randomness."
*/

// Run when document is loaded.
$(document).ready(function() {

  /* -- FUNCTTION DECLARATIONS -- */

  // validate nCards input to make sure is Number between 1 and 7
  function validateNCards() {
    if ($('#nCards').val() != ""){
      if (isNaN($('#nCards').val())) {
        alert('Please type a number between 1 and 7.');
        $('#nCards').val("");
      } else if ($('#nCards').val() < 1) {
        alert('Number of cards must be an integer greater than \'0\'.');
        $('#nCards').val("");
      } else if ($('#nCards').val() > 7) {
        alert('Number of cards must be an integer less than \'8\'.');
        $('#nCards').val("");
      }
    }
  }

  function validateNHands() {
    if ($('#nHands').val() != ""){
      if (isNaN($('#nHands').val())) {
        alert('Please type a number between 1 and 5.');
        $('#nHands').val("");
      } else if ($('#nHands').val() < 1) {
        alert('Number of hands must be an integer greater than \'0\'.');
        $('#nHands').val("");
      } else if ($('#nHands').val() > 5) {
        alert('Number of hands must be an integer less than \'6\'.');
        $('#nHands').val("");
      }
    }
  }

  // Create deck in array and shuffle cards
  function makeDeck() {

    /* -VARIABLE DECLARATIONS- */
    var suit = ['C', 'D', 'H', 'S'];
    var deck = [];

    // Create 52 Playing Cards
    for (var s = 0; s < suit.length; s++) {
      for (var i = 1; i < 14; i++) {
        deck.push(suit[s]+i);
      }
    }

    // Fisher-Yates Shuffle
    for (var i = deck.length-1; i > 0; i--){
      var j = Math.floor(Math.random()*(i+1));
      var temp = deck[i];
      deck[i] = deck[j];
      deck[j] = temp;
    }
    // Return Shuffled Deck
    return deck;
  }

  // Draw a set of i cards
  function drawCard(deck){
    var stringCard = "";
    var cardNumber = 0;

    // loop and make rows of cards based on #nHands input
    for (var i = 1; i < parseInt($('#nHands').val())+1; i++){
      stringCard += '<tr><td class="hand" colspan="'+
        parseInt($('#nCards').val()) +'">Hand Number '+ i +'</td></tr><tr>';
      // loop and make cells of cards based on nCards input
      for (var j = 0; j < parseInt($('#nCards').val()); j++) {
        stringCard += '<td><img src="assets/'+ deck[cardNumber] +'.png" alt="'+
          deck[cardNumber]+'"></td>';
        cardNumber += 1;
      }
      stringCard += '</tr>';
    }
    return stringCard;
  }

  /* ~ EVENT LISTENERS ~ */

  // onchange validate input of nCards after selection is made
  $('#nCards').on("change", function(){
    $('#nCards').on("blur", validateNCards());
  });

  // onchange validate inputs of nHands after selection is made
  $('#nHands').on("change", function(){
    $('#nHands').on("blur", validateNHands());
  });

  // onclick draw cards on the #draw table and validate inputs
  $('#draw').click(function(){
    if($('#nCards').val() == "" || $('#nHands').val() == "" ) {
      alert('Please input valid digits before proceeding.')
    } else {
      validateNCards();
      validateNHands();
      $('#data').html(drawCard(makeDeck()));
    }
  });
});
